@@ -87,7 +87,8 @@ class TraceContext (object):
                 wrappedSelf.__class__.__name__,
                 id(self),
                 m.__name__)
-            return self._trace_call(name, 1, m, wrappedSelf, args, kw)
+            fullArgs = (wrappedSelf,) + args
+            return self._trace_call(name, 1, m, fullArgs, kw)
         return wrapped
 
     def _wrap_function(self, f):
@@ -108,7 +109,7 @@ class TraceContext (object):
 
     def _trace_call(self, name, argStart, f, args, kw):
         argDesc = self._describeArgs(args[argStart:], kw)
-        self._log('{0} calling with {1}...', name, argDesc)
+        self._log('{0}{1}...', name, argDesc)
         try:
             self._depth += 1
             try:
@@ -116,10 +117,10 @@ class TraceContext (object):
             finally:
                 self._depth -= 1
         except Exception, e:
-            self._log('{0} raise {1!r}', name, e)
+            self._log('{0}{1} raising {2!r}', name, argDesc, e)
             raise
         else:
-            self._log('{0} return {1!r}', name, result)
+            self._log('{0}{1} -> {2!r}', name, argDesc, result)
             return result
 
     @staticmethod
